/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef bealh
#define bealh

#include <QDialog>
#include <con.h>

class QComboBox;
class QSpinBox;
class QTreeWidgetItem;
class QPushButton;
class beal : public QDialog
<%
	Q_OBJECT
	public:
		beal(QWidget *felvnl);
		QComboBox *mrtdt;
		QComboBox *kitzjl;
		QSpinBox *lnmtat;
		QPushButton *fldlgz;
		QColor kidlgz;

	public slots:
		void irnyjl();
%>;

#endif

